@@ -11,7 +11,7 @@
    San Rafael, CA  94903, U.S.A., +1(415)492-9861, for further information.
 */
 
-/* $Id: gdevpdfx.h 9373 2009-01-19 09:47:56Z ken $ */
+/* $Id: gdevpdfx.h 9876 2009-07-21 13:43:27Z ken $ */
 /* Internal definitions for PDF-writing driver. */
 
 #ifndef gdevpdfx_INCLUDED
@@ -653,6 +653,11 @@ struct gx_device_pdf_s {
     bool SetPageSize;
     bool RotatePages;
     bool FitPages;
+    bool CenterPages;
+    bool DoNumCopies;
+    bool PreserveSeparation;
+    bool PreserveDeviceN;
+    int PDFACompatibilityPolicy;
 };
 
 #define is_in_page(pdev)\
@@ -887,7 +892,7 @@ int pdf_write_and_free_all_resource_objects(gx_device_pdf *pdev);
  * Store the resource sets for a content stream (page or XObject).
  * Sets page->{procsets, resource_ids[], fonts_id}.
  */
-int pdf_store_page_resources(gx_device_pdf *pdev, pdf_page_t *page);
+int pdf_store_page_resources(gx_device_pdf *pdev, pdf_page_t *page, bool clear_usage);
 
 /* Copy data from a temporary file to a stream. */
 void pdf_copy_data(stream *s, FILE *file, long count, stream_arcfour_state *ss);
@@ -1212,7 +1217,7 @@ int pdf_char_image_y_offset(const gx_device_pdf *pdev, int x, int y, int h);
 
 /* Begin a CharProc for an embedded (bitmap) font. */
 int pdf_begin_char_proc(gx_device_pdf * pdev, int w, int h, int x_width,
-			int y_offset, gs_id id, pdf_char_proc_t **ppcp,
+			int y_offset, int x_offset, gs_id id, pdf_char_proc_t **ppcp,
 			pdf_stream_position_t * ppos);
 
 /* End a CharProc. */
